@@ -1,28 +1,25 @@
 /*
-    KMLOFax
-
-    A utility to process facsimiles received with the ELSA
-    MicroLink(tm) Office modem.
-
-    Copyright (C) 1999-2001 Oliver Gantz <Oliver.Gantz@epost.de>
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-    ------
-    ELSA and MicroLink are trademarks of ELSA AG, Aachen.
-*/
+ * KMLOFax
+ *
+ * A utility to process facsimiles received with a modem of the
+ * ELSA MicroLink Office family.
+ *
+ * Copyright (C) 1999,2000,2001,2002 Oliver Gantz <Oliver.Gantz@epost.de>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
 
 #include <stdlib.h>
 #include <string.h>
@@ -35,7 +32,7 @@
 #include <qdir.h>
 #include <qframe.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
 #include <kiconloader.h>
 #include <kmessagebox.h>
@@ -50,7 +47,7 @@
 
 
 
-ExportDlg::ExportDlg(QWidget *parent, const char *name) : KDialog (parent, name, true)
+ExportDlg::ExportDlg(QWidget *parent, const char *name): KDialog (parent, name, true)
 {
 	QBoxLayout *vbox, *hbox, *fvbox, *fhbox;
 	QGroupBox *gb;
@@ -71,7 +68,7 @@ ExportDlg::ExportDlg(QWidget *parent, const char *name) : KDialog (parent, name,
 	file = new QLineEdit(gb);
 	file->setMinimumWidth(240);
 	file->setFixedHeight(file->sizeHint().height());
-	file->setText("facsimile.tif");
+	file->setText(QDir::currentDirPath() + "/facsimile.tif");
 	fhbox->addWidget(file);
 
 	browse = new QPushButton(gb);
@@ -127,10 +124,8 @@ ExportDlg::ExportDlg(QWidget *parent, const char *name) : KDialog (parent, name,
 
 	compression = new QComboBox(false, gb);
 	l1->setBuddy(compression);
-	compression->insertItem(i18n(" None "), 0);
-	compression->insertItem(i18n(" CCITT Group 3 "), 1);
-	compression->insertItem(i18n(" LZW "), 2);
-	compression->insertItem(i18n(" Pack Bits "), 3);
+	compression->insertItem(i18n(" CCITT Group 3 "), 0);
+//	compression->insertItem(i18n(" None "), 1);
 	compression->setMinimumSize(compression->sizeHint());
 	fhbox->addWidget(compression);
 	fhbox->addStretch(1);
@@ -182,13 +177,13 @@ ExportDlg::~ExportDlg()
 }
 
 
-void ExportDlg::exportFax(const QString& name)
+void ExportDlg::exportFax(const QString &name)
 {
-	MLOFile mlofile;
+	TiffFile mlofile;
 
-	mlofile.setName(name);
+	mlofile.setName(expandPath(name));
 
-	if (!mlofile.open()) {
+	if (!mlofile.open(IO_ReadOnly)) {
 		KMessageBox::sorry(this, i18n("Cannot open facsimile file."), i18n("File Error"));
 		return;
 	}
@@ -218,17 +213,17 @@ void ExportDlg::slotBrowse()
 
 void ExportDlg::slotHelp()
 {
-	kapp->invokeHelp("EXPORT-HELP");
+	kapp->invokeHelp("export-help");
 }
 
 
 void ExportDlg::slotOk()
 {
-	MLO2TiffFilter filter;
+	Tiff2TiffFilter filter;
 
-	filter.setFile(m_name);
+	filter.setFile(expandPath(m_name));
 	filter.setRange(from_page->value(), to_page->value());
-	filter.setCompression(compression->currentItem());
+//	filter.setCompression(compression->currentItem());
 
 	kapp->setOverrideCursor(waitCursor);
 
