@@ -1,35 +1,32 @@
 /*
-    KMLOFax
-    
-    A utility to process facsimiles received with the ELSA
-    MicroLink(tm) Office modem.
-
-    Copyright (C) 1999-2001 Oliver Gantz <Oliver.Gantz@epost.de>
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-    ------
-    ELSA and MicroLink are trademarks of ELSA AG, Aachen.
-*/
+ * KMLOFax
+ *
+ * A utility to process facsimiles received with a modem of the
+ * ELSA MicroLink Office family.
+ *
+ * Copyright (C) 1999,2000,2001,2002 Oliver Gantz <Oliver.Gantz@epost.de>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
 
 #include <stdlib.h>
 #include <string.h>
 
 #include <qdatetime.h>
 
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <klocale.h>
 #include <kglobal.h>
 
@@ -37,9 +34,6 @@
 
 
 
-bool got_sigpipe = false;
-
-
 const uchar xchg_endian[256] = {
 	0x00, 0x80, 0x40, 0xc0, 0x20, 0xa0, 0x60, 0xe0,
 	0x10, 0x90, 0x50, 0xd0, 0x30, 0xb0, 0x70, 0xf0,
@@ -76,43 +70,37 @@ const uchar xchg_endian[256] = {
 };
 
 
-QString expandPath(const QString& fname)
+QString expandPath(const QString &fname)
 {
 	return locateLocal("appdata", fname);
 }
 
 
-QString mloDateStr(const char *name)
+QString mloDateStr(const QString &name)
 {
-	int year, month, day, hour, minute, second;
-	QDate date;
-	QTime time;
+	QDateTime datetime;
 
-	mloDateSplit(name, &year, &month, &day, &hour, &minute, &second);
+	datetime = mloDateSplit(name);
 	
-	date.setYMD(year, month, day);
-	time.setHMS(hour, minute, second);
-
-	return KGlobal::locale()->formatDate(date, true) + " (" + KGlobal::locale()->formatTime(time, true) + ")";
+	return KGlobal::locale()->formatDate(datetime.date(), true) + " (" + KGlobal::locale()->formatTime(datetime.time(), true) + ")";
 }
 
 
-void mloDateSplit(const char *name, int *year, int *month, int *day, int *hour, int *minute, int *second)
+QDateTime mloDateSplit(const QString &name)
 {
-	char buffer[15];
+	QDateTime datetime;
+	int year, month, day, hour, minute, second;
+	int pos = name.findRev('/') + 1;
+	
+	year   = name.mid(pos    , 4).toInt();
+	month  = name.mid(pos + 4, 2).toInt();
+	day    = name.mid(pos + 6, 2).toInt();
+	hour   = name.mid(pos + 8, 2).toInt();
+	minute = name.mid(pos +10, 2).toInt();
+	second = name.mid(pos +12, 2).toInt();
 
-	strncpy(buffer, name, 14);
-	buffer[14] = 0;
+	datetime.setDate(QDate(year, month, day));
+	datetime.setTime(QTime(hour, minute, second));
 
-	*second = atoi(&(buffer[12]));
-	buffer[12] = 0;
-	*minute = atoi(&(buffer[10]));
-	buffer[10] = 0;
-	*hour = atoi(&(buffer[8]));
-	buffer[8] = 0;
-	*day = atoi(&(buffer[6]));
-	buffer[6] = 0;
-	*month = atoi(&(buffer[4]));
-	buffer[4] = 0;
-	*year = atoi(buffer);
+	return datetime;
 }
