@@ -1,28 +1,25 @@
 /*
-    KMLOFax
-    
-    A utility to process facsimiles received with the ELSA
-    MicroLink(tm) Office modem.
-
-    Copyright (C) 1999-2001 Oliver Gantz <Oliver.Gantz@epost.de>
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-    ------
-    ELSA and MicroLink are trademarks of ELSA AG, Aachen.
-*/
+ * KMLOFax
+ *
+ * A utility to process facsimiles received with a modem of the
+ * ELSA MicroLink Office family.
+ *
+ * Copyright (C) 1999,2000,2001,2002 Oliver Gantz <Oliver.Gantz@epost.de>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
 
 #include <stdlib.h>
 #include <time.h>
@@ -36,14 +33,14 @@
 #include <qfont.h>
 #include <qpushbutton.h>
 #include <qtooltip.h>
+#include <qglobal.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kseparator.h>
 
 #include "maildlg.h"
-#include "filters.h"
 #include "mlofile.h"
 #include "senderaliases.h"
 #include "global.h"
@@ -51,7 +48,7 @@
 
 
 
-MailClient::MailClient() : DwSmtpClient()
+MailClient::MailClient(): DwSmtpClient()
 {
 	connected = false;
 	srand(time(0));
@@ -65,7 +62,7 @@ MailClient::~MailClient()
 }
 
 
-bool MailClient::SendDataMult(const DwString& aStr)
+bool MailClient::SendDataMult(const DwString &aStr)
 {
 	return SendDataMult(aStr.data(), aStr.length());
 }
@@ -170,48 +167,96 @@ bool MailClient::sendBody(const char *body)
 
 bool MailClient::sendFile(FILE *stream)
 {
+	char alphabet[64];
 	DwString msg;
-	char buff[258];
-	int i;
+	unsigned char ibuff[3000], c1, c2, c3;
+	char obuff[80];
+	size_t i, j, pad, result;
 	QProgressDialog *prog;
 
+	for (i=0; i < 26; i++) {
+		alphabet[i] = 'A' + i;
+		alphabet[26 + i] = 'a' + i;
+	}
+	for (i=0; i < 10; i++)
+		alphabet[52 + i] = '0' + i;
+	alphabet[62] = '+';
+	alphabet[63] = '/';
+		
 	fseek(stream, 0, SEEK_END);
 	
 	msg.assign("--");
 	msg.append(boundary);
-	msg.append("\r\012Content-Type: application/postscript; name=\"facsimile.ps\"\r\012");
-	msg.append("Content-Transfer-Encoding: 7bit\r\012");
-	msg.append("Content-Disposition: attachment; filename=\"facsimile.ps\"\r\012\r\012");
+	msg.append("\r\012Content-Type: image/tiff; name=\"facsimile.tif\"\r\012");
+	msg.append("Content-Transfer-Encoding: base64\r\012");
+	msg.append("Content-Disposition: attachment; filename=\"facsimile.tif\"\r\012\r\012");
 
 	if (!SendDataMult(msg)) {
 		return false;
 	}
 
 	prog = new QProgressDialog(i18n("Sending mail..."), i18n("Cancel"), (int)ftell(stream), 0, "mailprogress", true);
-	CHECK_PTR(prog);
+	Q_CHECK_PTR(prog);
 	prog->setCaption(i18n("Mail Sending"));
 
 	rewind(stream);
 	prog->setProgress(0);
 	
-	while (fgets(buff, 256, stream)) {
+	j = 0;
+	while ((result = fread((void *)ibuff, 1, 3000, stream)) > 0) {
 		if (prog->wasCancelled()) {
 			delete prog;
 			return false;
 		}
 
-		i = strlen(buff);
-		if (i &&  buff[i-1] == '\n')
-			i--;
-		buff[i++] = '\r';
-		buff[i++] = '\012';
-		buff[i] = 0;
-		if (!SendDataMult(buff, i)) {
+		i = 0;
+		while (i < result) {
+			c1 = ibuff[i++];
+			if (i >= result) {
+				pad = 2;
+				c2 = 0;
+				c3 = 0;
+			} else {
+				c2 = ibuff[i++];
+				if (i >= result) {
+					pad = 1;
+					c3 = 0;
+				} else {
+					c3 = ibuff[i++];
+					pad = 0;
+				}
+			}
+			obuff[j++] = alphabet[c1 >> 2];
+			obuff[j++] = alphabet[((c1 << 4) | (c2 >> 4)) & 0x3f];
+			if (pad < 2)
+				obuff[j++] = alphabet[((c2 << 2) | (c3 >> 6)) & 0x3f];
+			else
+				obuff[j++] = '=';
+			if (pad < 1)
+				obuff[j++] = alphabet[c3 & 0x3f];
+			else
+				obuff[j++] = '=';
+			if (j >= 76) {
+				obuff[j++] = '\r';
+				obuff[j++] = '\012';
+				obuff[j] = 0;
+				if (!SendDataMult(obuff, j)) {
+					delete prog;
+					return false;
+				}
+				j = 0;
+			}
+		}
+		prog->setProgress((int)ftell(stream));
+	}
+	if (j) {
+		obuff[j++] = '\r';
+		obuff[j++] = '\012';
+		obuff[j] = 0;
+		if (!SendDataMult(obuff, j)) {
 			delete prog;
 			return false;
 		}
-
-		prog->setProgress((int)ftell(stream));
 	}
 
 	delete prog;
@@ -286,7 +331,7 @@ MailDlg::MailDlg(QWidget *parent, const char *name) : KDialog (parent, name, tru
 	
 	vbox->addWidget(body, 1);
 
-	label = new QLabel(QString("%1: facsimile.ps (application/postscript)").arg(i18n("Attachment")), this);
+	label = new QLabel(QString("%1: facsimile.tif (image/tiff)").arg(i18n("Attachment")), this);
 	label->setMinimumSize(label->sizeHint());
 	label->setFrameStyle(QFrame::Panel|QFrame::Sunken);
 	
@@ -338,15 +383,15 @@ MailDlg::~MailDlg()
 }
 
 
-void MailDlg::mailFax(const QString& name)
+void MailDlg::mailFax(const QString &name)
 {
 	QString sender;
-	MLOFile mlofile;
+	TiffFile tifffile;
 	
-	mlofile.setName(name);
-	if (mlofile.open()) {
-		sender = SENDER_ALIAS(mlofile.sender());
-		mlofile.close();
+	tifffile.setName(expandPath(name));
+	if (tifffile.open(IO_ReadOnly)) {
+		sender = SENDER_ALIAS(tifffile.sender());
+		tifffile.close();
 	}
 	
 	m_name = name;
@@ -362,7 +407,7 @@ void MailDlg::mailFax(const QString& name)
 
 void MailDlg::slotHelp()
 {
-	kapp->invokeHelp("MAIL-HELP");
+	kapp->invokeHelp("mail-help");
 }
 
 
@@ -371,7 +416,6 @@ void MailDlg::slotSend()
 	MailClient mclient;
 	QString from, server, name, org, email, reply;
 	int port;
-	MLO2PSFilter filter;
 	FILE *f;
 	
 	config->setGroup(ID_PREF_GROUP_MAIL);
@@ -392,12 +436,12 @@ void MailDlg::slotSend()
 		return;
 	}
 
-	if (!*(header_to->text())) {
+	if (header_to->text().isEmpty()) {
 		KMessageBox::sorry(this, i18n("No receiver specified."), i18n("Mail Error"));
 		return;
 	}
 
-	if (!mclient.connect(server, port)) {
+	if (!mclient.connect(server.latin1(), port)) {
 		KMessageBox::sorry(this, i18n("Cannot connect to server."), i18n("SMTP Error"));
 		return;
 	}
@@ -412,28 +456,20 @@ void MailDlg::slotSend()
 		from += ">";
 	}
 
-	if (!mclient.sendHeader(from.data(), header_to->text(), header_subject->text())) {
+	if (!mclient.sendHeader(from.latin1(), header_to->text().latin1(), header_subject->text().latin1())) {
 		KMessageBox::sorry(this, i18n("Cannot send mail header."), i18n("SMTP Error"));
 		mclient.disconnect();
 		return;
 	}
 
-	if (!mclient.sendBody(body->text().data())) {
+	if (!mclient.sendBody(body->text().latin1())) {
 		KMessageBox::sorry(this, i18n("Cannot send mail body."), i18n("SMTP Error"));
 		mclient.disconnect();
 		return;
 	}
 
-	if (!(f = tmpfile())) {
-		KMessageBox::sorry(this, i18n("Cannot create temporary file."), i18n("SMTP Error"));
-		mclient.disconnect();
-		return;
-	}
-	
-	filter.setFile(m_name);
-	
-	if (!filter.convertFile(f)) {
-		fclose(f);
+	if (!(f = fopen(expandPath(m_name).latin1(), "r"))) {
+		KMessageBox::sorry(this, i18n("Cannot open facsimile file."), i18n("SMTP Error"));
 		mclient.disconnect();
 		return;
 	}
