@@ -1,28 +1,25 @@
 /*
-    KMLOFax
-    
-    A utility to process facsimiles received with the ELSA
-    MicroLink(tm) Office modem.
-
-    Copyright (C) 1999-2001 Oliver Gantz <Oliver.Gantz@epost.de>
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-    ------
-    ELSA and MicroLink are trademarks of ELSA AG, Aachen.
-*/
+ * KMLOFax
+ *
+ * A utility to process facsimiles received with a modem of the
+ * ELSA MicroLink Office family.
+ *
+ * Copyright (C) 1999,2000,2001,2002 Oliver Gantz <Oliver.Gantz@epost.de>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
 
 #include <qglobal.h>
 #include <qframe.h>
@@ -33,7 +30,7 @@
 #include <qtooltip.h>
 #include <qfile.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <ksimpleconfig.h>
@@ -59,12 +56,12 @@ EditAlias::EditAlias(QWidget *parent, const char *name) : KDialog (parent, name,
 	QSize size;
 
 	vbox = new QVBoxLayout(this, marginHint());
-	CHECK_PTR(vbox);
+	Q_CHECK_PTR(vbox);
 
 	vbox->addStretch();
 
 	grid = new QGridLayout(2, 2);
-	CHECK_PTR(grid);
+	Q_CHECK_PTR(grid);
 	vbox->addLayout(grid);
 
 	label = new QLabel(i18n("&Sender ID:"), this);
@@ -143,7 +140,7 @@ SenderAliases::SenderAliases(QWidget *parent, const char *name) : KDialog (paren
 	gvbox = new QVBoxLayout(gb, marginHint());
 	
 	list = new QListView(gb, "aliaslist");
-	CHECK_PTR(list);
+	Q_CHECK_PTR(list);
 	list->addColumn(i18n("Sender ID"));
 	list->addColumn(i18n("Alias"));
 	list->setColumnWidth(0, 200);
@@ -155,7 +152,7 @@ SenderAliases::SenderAliases(QWidget *parent, const char *name) : KDialog (paren
 	gvbox->addWidget(list, 1);
 
 	ghbox = new QHBoxLayout();
-	CHECK_PTR(ghbox);
+	Q_CHECK_PTR(ghbox);
 	gvbox->addLayout(ghbox);
 
 	add_item = new QPushButton(i18n("&Add"), gb);
@@ -196,7 +193,7 @@ SenderAliases::SenderAliases(QWidget *parent, const char *name) : KDialog (paren
 
 	vbox->activate();
 
-	connect(list, SIGNAL(selectionChanged(QListViewItem *)), SLOT(selectionChangedSlot(QListViewItem *)));
+	connect(list, SIGNAL(currentChanged(QListViewItem *)), SLOT(currentChangedSlot(QListViewItem *)));
 	connect(list, SIGNAL(doubleClicked(QListViewItem *)), SLOT(executedSlot(QListViewItem *)));
 	connect(list, SIGNAL(returnPressed(QListViewItem *)), SLOT(executedSlot(QListViewItem *)));
 	connect(add_item, SIGNAL(clicked()), SLOT(addItem()));
@@ -225,17 +222,19 @@ void SenderAliases::loadDir()
 	list->clear();
 
 	sconfig = new KSimpleConfig(expandPath(KMLOFAX_ALIASLIST), true);
-	CHECK_PTR(sconfig);
+	Q_CHECK_PTR(sconfig);
 	sconfig->setGroup("General");
 	number = sconfig->readNumEntry("Entries");
 	for (i = 0; i < number; i++) {
 		sconfig->setGroup(QString("Entry %1").arg(i));
 		item = new QListViewItem(list);
-		CHECK_PTR(item);
+		Q_CHECK_PTR(item);
 		item->setText(0, sconfig->readEntry("Sender"));
 		item->setText(1, sconfig->readEntry("Alias"));
 	}
 	delete sconfig;
+
+	currentChangedSlot(list->currentItem());
 }
 
 
@@ -247,7 +246,7 @@ void SenderAliases::saveDir()
 
 	QFile::remove(expandPath(KMLOFAX_ALIASLIST));
 	sconfig = new KSimpleConfig(expandPath(KMLOFAX_ALIASLIST), false);
-	CHECK_PTR(sconfig);
+	Q_CHECK_PTR(sconfig);
 	sconfig->setGroup("General");
 	sconfig->writeEntry("Entries", list->childCount());
 	item = list->firstChild();
@@ -282,7 +281,7 @@ void SenderAliases::addToolTips(bool on)
 }	
 
 
-QString SenderAliases::alias(const QCString& id_)
+QString SenderAliases::alias(const QString& id_)
 {
 	QListViewItem *item;
 	QString s = id_.stripWhiteSpace();
@@ -298,7 +297,7 @@ QString SenderAliases::alias(const QCString& id_)
 }
 
 
-void SenderAliases::setAlias(const QCString& id_)
+void SenderAliases::setAlias(const QString& id_)
 {
 	QListViewItem *item;
 	QString s = id_.stripWhiteSpace();
@@ -315,7 +314,7 @@ void SenderAliases::setAlias(const QCString& id_)
 		item->setText(0, s);
 	}
 
-	list->setSelected(item, true);
+	list->setCurrentItem(item);
 	list->ensureItemVisible(item);
 
 	if (isVisible())
@@ -325,12 +324,10 @@ void SenderAliases::setAlias(const QCString& id_)
 }
 
 
-void SenderAliases::selectionChangedSlot(QListViewItem *item)
+void SenderAliases::currentChangedSlot(QListViewItem *item)
 {
-	if (item) {
-		edit_item->setEnabled(true);
-		del_item->setEnabled(true);
-	}
+	edit_item->setEnabled(item != 0);
+	del_item->setEnabled(item != 0);
 }
 
 
@@ -380,10 +377,10 @@ void SenderAliases::deleteItem()
 	QListViewItem *item;
 
 	if ((item = list->currentItem())) {
-		if (KMessageBox::questionYesNo(this, i18n("Really delete entry\n\"%1\"?").arg(item->text(0)), i18n("Question"), i18n("&Delete"), i18n("&Cancel")) == KMessageBox::Yes) {
-			delete item;
+		if (KMessageBox::warningYesNo(this, i18n("Really delete entry\n\"%1\"?").arg(item->text(0)), i18n("Question"), i18n("&Delete"), i18n("&Cancel")) == KMessageBox::Yes) {
 			edit_item->setEnabled(false);
 			del_item->setEnabled(false);
+			delete item;
 			saveDir();
 			emit applyButtonPressed();
 		}
@@ -393,5 +390,5 @@ void SenderAliases::deleteItem()
 
 void SenderAliases::slotHelp()
 {
-	kapp->invokeHelp("SENDERALIASES-HELP");
+	kapp->invokeHelp("senderaliases-help");
 }
