@@ -1,28 +1,25 @@
 /*
-    KMLOFax
-    
-    A utility to process facsimiles received with the ELSA
-    MicroLink(tm) Office modem.
-
-    Copyright (C) 1999-2001 Oliver Gantz <Oliver.Gantz@epost.de>
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-    ------
-    ELSA and MicroLink are trademarks of ELSA AG, Aachen.
-*/
+ * KMLOFax
+ *
+ * A utility to process facsimiles received with a modem of the
+ * ELSA MicroLink Office family.
+ *
+ * Copyright (C) 1999,2000,2001,2002 Oliver Gantz <Oliver.Gantz@epost.de>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
 
 #ifndef SENDERALIASES_H 
 #define SENDERALIASES_H 
@@ -33,7 +30,6 @@
 
 #include <qwidget.h>
 #include <qstring.h>
-#include <qcstring.h>
 #include <qlistview.h>
 #include <qlineedit.h>
 #include <qpushbutton.h>
@@ -93,11 +89,11 @@ public:
 	void addToolTips(bool on);
 
 public slots:
-	QString alias(const QCString& id_);
-	void setAlias(const QCString& id_);
+	QString alias(const QString& id_);
+	void setAlias(const QString& id_);
 
 protected slots:
-	void selectionChangedSlot(QListViewItem *item);
+	void currentChangedSlot(QListViewItem *item);
 	void executedSlot(QListViewItem *);
 	void addItem();
 	void editItem();
